summaryrefslogtreecommitdiff
path: root/pkgs/development/libraries/gdk-pixbuf/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/libraries/gdk-pixbuf/default.nix')
-rw-r--r--pkgs/development/libraries/gdk-pixbuf/default.nix50
1 files changed, 27 insertions, 23 deletions
diff --git a/pkgs/development/libraries/gdk-pixbuf/default.nix b/pkgs/development/libraries/gdk-pixbuf/default.nix
index 2d8e60d06a73..fd2d62a032c3 100644
--- a/pkgs/development/libraries/gdk-pixbuf/default.nix
+++ b/pkgs/development/libraries/gdk-pixbuf/default.nix
@@ -7,16 +7,15 @@
, pkg-config
, gettext
, python3
-, libxml2
, libxslt
, docbook-xsl-nons
, docbook_xml_dtd_43
-, gtk-doc
+, gi-docgen
, glib
, libtiff
, libjpeg
, libpng
-, gnome3
+, gnome
, gobject-introspection
, doCheck ? false
, makeWrapper
@@ -25,13 +24,13 @@
stdenv.mkDerivation rec {
pname = "gdk-pixbuf";
- version = "2.42.2";
+ version = "2.42.6";
outputs = [ "out" "dev" "man" "devdoc" "installedTests" ];
src = fetchurl {
url = "mirror://gnome/sources/${pname}/${lib.versions.majorMinor version}/${pname}-${version}.tar.xz";
- sha256 = "05ggmzwvrxq9w4zcvmrnnd6qplsmb4n95lj4q607c7arzlf6mil3";
+ sha256 = "0zz7pmw2z46g7mr1yjxbsdldd5pd03xbjc58inj8rxfqgrdvg9n4";
};
patches = [
@@ -45,14 +44,15 @@ stdenv.mkDerivation rec {
pkg-config
gettext
python3
- libxml2
- libxslt
- docbook-xsl-nons
- docbook_xml_dtd_43
- gtk-doc
gobject-introspection
makeWrapper
glib
+ gi-docgen
+
+ # for man pages
+ libxslt
+ docbook-xsl-nons
+ docbook_xml_dtd_43
] ++ lib.optional stdenv.isDarwin fixDarwinDylibNames;
propagatedBuildInputs = [
@@ -75,19 +75,26 @@ stdenv.mkDerivation rec {
substituteInPlace tests/meson.build --subst-var-by installedtestsprefix "$installedTests"
'';
+ preInstall = ''
+ PATH=$PATH:$out/bin # for install script
+ '';
+
postInstall =
- # meson erroneously installs loaders with .dylib extension on Darwin.
- # Their @rpath has to be replaced before gdk-pixbuf-query-loaders looks at them.
- lib.optionalString stdenv.isDarwin ''
+ ''
+ # All except one utility seem to be only useful during building.
+ moveToOutput "bin" "$dev"
+ moveToOutput "bin/gdk-pixbuf-thumbnailer" "$out"
+
+ # So that devhelp can find this.
+ mkdir -p "$devdoc/share/devhelp"
+ mv "$out/share/doc" "$devdoc/share/devhelp/books"
+ '' + lib.optionalString stdenv.isDarwin ''
+ # meson erroneously installs loaders with .dylib extension on Darwin.
+ # Their @rpath has to be replaced before gdk-pixbuf-query-loaders looks at them.
for f in $out/${passthru.moduleDir}/*.dylib; do
install_name_tool -change @rpath/libgdk_pixbuf-2.0.0.dylib $out/lib/libgdk_pixbuf-2.0.0.dylib $f
mv $f ''${f%.dylib}.so
done
- ''
- # All except one utility seem to be only useful during building.
- + ''
- moveToOutput "bin" "$dev"
- moveToOutput "bin/gdk-pixbuf-thumbnailer" "$out"
'' + lib.optionalString (stdenv.hostPlatform == stdenv.buildPlatform) ''
# We need to install 'loaders.cache' in lib/gdk-pixbuf-2.0/2.10.0/
$dev/bin/gdk-pixbuf-query-loaders --update-cache
@@ -100,10 +107,6 @@ stdenv.mkDerivation rec {
done
'';
- preInstall = ''
- PATH=$PATH:$out/bin # for install script
- '';
-
# The tests take an excessive amount of time (> 1.5 hours) and memory (> 6 GB).
inherit doCheck;
@@ -112,8 +115,9 @@ stdenv.mkDerivation rec {
separateDebugInfo = stdenv.isLinux;
passthru = {
- updateScript = gnome3.updateScript {
+ updateScript = gnome.updateScript {
packageName = pname;
+ versionPolicy = "odd-unstable";
};
tests = {